%read in the promoter sequence
[ATF2_sequence,label]=readfastaseqs('ATF2.fa');

%use the number representation of bases (A=1, C=2, G=3, T=4)
Atf2_c=basepairs2num(ATF2_sequence{1});

%as the sequence was the complement of the promoter, we need to take
%complement

ATF2=complement(Atf2_c);

% read in the PSSMs

% matrix V$AP1_C from TRANSFAC 7.0 public release

AP1=[4.79 0.00 0.00 11.28 1.28 0.00 1.46 12.15 0.89 
2.30 0.00 0.00 0.00 4.71 0.00 10.70 0.00 1.22 
3.06 0.00 9.83 0.00 6.16 0.00 0.00 0.00 5.91 
1.30 12.15 2.32 0.87 0.00 12.15 0.00 0.00 2.17 ];

% matrix V$CMYB_01 from TRANSFAC 7.0 public release

MYB=[1 6 6 16 16 9 8 20 4 18 0 0 0 11 6 1 2 1 
12 15 10 5 11 16 4 1 49 18 0 0 0 1 6 7 2 0 
6 5 9 14 8 8 34 25 2 20 60 0 0 47 21 15 12 11 
8 1 5 3 2 16 5 5 5 4 0 60 60 1 5 11 4 1 
];

% matrix V$SP1_Q6 from TRANSFAC 7.0 public release

SP1=[32 24 14 17 0 0 19 2 0 21 17 3 9 
21 20 10 1 0 2 80 5 1 5 10 55 40 
35 56 65 89 108 106 0 99 99 76 72 21 32 
20 8 19 1 0 0 9 2 8 6 9 29 27 
];

% matrix V$USF_01 from TRANSFAC 7.0 public release

USF=[13 7 19 6 0 56 0 3 0 0 20 3 10 5 
7 6 3 16 58 1 55 0 1 0 4 17 17 11 
11 17 17 4 0 1 0 55 1 58 16 3 6 7 
5 10 3 20 0 0 3 0 56 0 6 19 7 13 
];

%do a cell array of the matrices

matrices={AP1,MYB, SP1,USF};

% numerical labels for the motifs 1->AP1, 2->MYB, 3->SP1, 4->USF 
labels_num=1:4;

%normalize and add pseudocounts to matrices

for i=1:length(matrices)
    ap = matrices{i};
    ap=ap+0.01;
    ap = ap./(ones(4,1)*sum(ap,1));
    matrices{i}=ap;
end

%we use zeroth order background with equal probabilities for bases

bg=[0.25, 0.25,0.25,0.25];

%offset is 0 as we use 0th order model
offset = 0;

%we do not have any positional prior, here you could add for example
%conservation data
PP=[];

% An initial parse.
T = [];

% MCMC sampler parameters, we use 10000 burn-in samples and after that we
% sample in the sets of 10000 until the convergence is reached (t=0.01). As
% diagtype is 2, the convergence is achieved by comparing two independently
% runned chains
burnin = 10000;
samples = 10000;
maxsamples = 1000000;
t = 0.01;
diagtype = 2;


[Pc,c_mu,priorA] = TFBS_DF_Likelihood(ATF2,PP,matrices,bg,0);

[postnm1, postloc1, postlocind1, postTF1, postcomb1, totalsamples1] = TFBS_DF_Bayes_MCMC_MultiTF_convdiag(ATF2,PP,offset,bg,matrices,labels_num,priorA,T,burnin,samples,maxsamples,t,diagtype);
   
%with interactions we need also a symmetric interactions-matrix, where 1 means that
%corresponding motifs interact 
      
interactions_matrix=[     1     0     1     0
                          0     0     0     0
                          1     0     1     0
                          0     0     0     1];

%As a the weighting coefficient for the interacting motif pair we use 3 and for the
%maximum distance for weighting  80 nucleotides for the piecewise prior

distance=80;
weight=3;

[postnm2, postloc2, postlocind2, postTF2, postcomb2, totalsamples2] = TFBS_DF_Bayes_MCMC_MultiTF_ppi_convdiag_piecewiseprior(ATF2,PP,offset,bg,matrices,labels_num,priorA,T,burnin,samples,maxsamples,t,diagtype, interactions_matrix, distance, weight);
        
%As a the weighting coefficient for the interacting motif pair we use 3 and for the
%maximum distance for weighting  80 nucleotides for the triangular prior

distance=60;
weight=4;

[postnm3, postloc3, postlocind3, postTF3, postcomb3, totalsamples3] = TFBS_DF_Bayes_MCMC_MultiTF_ppi_convdiag_triangularprior(ATF2,PP,offset,bg,matrices,labels_num,priorA,T,burnin,samples,maxsamples,t,diagtype, interactions_matrix, distance, weight);
    

[postnm3, postloc3, postlocind3, postTF3, postcomb3, totalsamples3] = TFBS_DF_Bayes_MCMC_MultiTF_ppi_convdiag_triangularprior(ATF2,PP,offset,bg,matrices,labels_num,priorA,T,burnin,samples,maxsamples,t,diagtype, interactions_matrix, distance);
 
%we can now plot the predicted binding sites and the affinities for
%different promoters along the promoter(the posterior distribution, the places of the start
%sites of the bound TF are the peaks)

%for MultiTF

figure;plot(postlocind1')
legend('AP1', 'MYB', 'SP1', 'TEAD')
xlabel('position on promoter')
ylabel('binding probability')
axis([0,length(ATF2),0,1])

%for MultiTF-PPI with piece wise flat prior 

figure;plot(postlocind2')
legend('AP1', 'MYB', 'SP1', 'TEAD')
xlabel('position on promoter')
ylabel('binding probability')
axis([0,length(ATF2),0,1])

%for MultiTF-PPI with triangular prior

figure;plot(postlocind3')
legend('AP1', 'MYB', 'SP1', 'TEAD')
xlabel('position on promoter')
ylabel('binding probability')
axis([0,length(ATF2),0,1])